# Simple python library to test how to upload to pypy
def add_numbers(num1, num2):
    return num1 + num2

def susbtract_numbers(num1, num2):
    return num1 - num2

def multipy_numbers(num1, num2):
    return num1 * num2

def devide_numbers(num1, num2):
    return num1 / num2